import { LitElement } from "lit";
import { ScaleType, Interpolator, ChangedProps, TickFormatter } from "./types";
export declare class ColorLegendElement extends LitElement {
    static styles: import("lit").CSSResult[];
    /**
     * The title text that displays at the top of the legend
     */
    titleText: string;
    /**
     * The width of the SVG or categorical legend div element
     */
    width: number;
    /**
     * The height of the SVG element
     */
    height: number;
    /**
     * The spacing between the legend bar and top most extent of the SVG
     */
    marginTop: number;
    /**
     * The spacing between the legend bar and right most extent of the SVG
     */
    marginRight: number;
    /**
     * The spacing between the legend bar and bottom most extent of the SVG
     */
    marginBottom: number;
    /**
     * The spacing between the legend bar and left most extent of the SVG
     */
    marginLeft: number;
    /**
     * The type of legend to render based on d3-scale
     */
    scaleType: ScaleType;
    /**
     * The color scale's domain values
     */
    domain: number[] | string[];
    /**
     * The color scale's range values
     */
    range: string[];
    /**
     * The symbology used for categorical legends
     */
    markType: import("./types").MarkType;
    /**
     * The desired number of axis ticks
     */
    ticks: number;
    /**
     * The d3-format specifier to format axis tick values
     */
    tickFormat: string;
    /**
     * The size or length of the axis ticks
     */
    tickSize: number;
    /**
     * The explicit values to be used for axis ticks
     */
    tickValues: number[];
    /**
     * Reference to the SVG node
     */
    svg: SVGSVGElement;
    /**
     * a color interpolator function such as one from d3-scale-chromatic
     */
    private _interpolator;
    get interpolator(): Interpolator<string>;
    set interpolator(value: Interpolator<string>);
    /**
     * Function that formats the xAxis tick values, set internally but may also be set externally
     */
    private _tickFormatter;
    get tickFormatter(): TickFormatter;
    set tickFormatter(value: TickFormatter);
    /**
     * Handles configuring the colorScale
     */
    private colorScaleSetter;
    /**
     * A type of d3-scale for applying color values to the legend item(s),
     * set internally by the colorScaleSetter.
     */
    get colorScale(): import("./types").ColorScale;
    /**
     * Configures the x scale and axis ticks
     */
    private axisTickSetter;
    /**
     * A d3 linear scale used for generating axis ticks,
     * set internally by the axisTickSetter
     */
    get xScale(): import("./types").XScale;
    /**
     * Handles rendering of HTML/SVG markup from the scaleType
     */
    private renderer;
    /**
     * Invoked on each update to perform rendering tasks. This method may return any
     * value renderable by lit-html's ChildPart - typically a TemplateResult
     * @returns TemplateResult
     */
    render(): import("lit-html").TemplateResult<1>;
    /**
     * Lit lifecycle method that is called before an update to the component's DOM
     * @param changedProps: ChangedProps
     */
    willUpdate(changedProps: ChangedProps): void;
}
declare global {
    interface HTMLElementTagNameMap {
        "color-legend": ColorLegendElement;
    }
}
//# sourceMappingURL=color-legend-element.d.ts.map